class SubjectBuilder < Builder
  extend RepositoriesProxy

  ##
  # receive a list of ids and return a list of subjects
  #
  # Example:
  #   subject = SubjectBuilder.build '#15:135'
  #   subjects = SubjectBuilder.build [{'@rid' => '#15:135'}, {'@rid' => '#15:140'}, {'@rid' => '#15:136'}]
  #   subjects = SubjectBuilder.build [{'@rid' => '#15:135', 'last_modified' => '2015-30-10 15:44:12'}, {'@rid' => '#15:140'}, {'@rid' => '#15:136'}]
  def self.build(subjects = [])
    array = []
    subjects = [subjects] if subjects.class == String
    subjects.each do |subject|
      unless subject['@rid'].blank?
        o = Rails.cache.fetch(cache_key(subject['@rid'], subject['last_modified'])) unless subject['last_modified'].blank?
        o = subject_repository.find subject['@rid'] if o.nil?
        array << o
      end
    end
    array
  end

  def self.build_from_orientdb(args = {})
    subject = nil

    unless args.nil?
      # cache object when build
      subject = Rails.cache.fetch(cache_key(args['@rid'], args['last_modified']), expires_in: 12.hours) do
        Subject.new(
            id: args['@rid'],
            name: args['name'],
            created_at: args['name'],
            last_modified: args['name']
        )
      end
    end

    subject
  end

end
